@@ -5,8 +5,8 @@ pub mod extensions;
 /// Common future types used by `hrpc-rs`.
 pub mod future;
 /// Common code to work with sockets.
-#[cfg(any(feature = "client", feature = "server"))]
+#[cfg(feature = "_common")]
 pub mod socket;
 /// Common code to work with transports.
-#[cfg(any(feature = "client", feature = "server"))]
+#[cfg(feature = "_common")]
 pub mod transport;
